pilas.widget_log.WidgetLog

Package pilas :: Module widget_log :: Class WidgetLog |
[hide private]
[frames] | no frames]

# Class WidgetLog

source code

    PyQt4.QtGui.QMainWindow --+
                              |
                             WidgetLog

Representa una ventana de log. Mediante pilas.log.imprimir() añadiremos elementos a esta ventana

Instance Methods | [hide private]
__init__(self) | source code
_initUI(self) | source code
_ejecutar(self) | source code
_pausar(self) | source code
_resetear(self) | source code
_ruta_icono(self, icono) | source code
imprimir(self, params) | source code
_insertar_elemento(self, elemento, elemento_padre=None) | source code
_contiene_diccionario(self, valor) | source code
_obtener_diccionario(self, valor) | source code
_insertar_texto_en_lista(self, texto, itemPadre=None) | source code
_insertar_diccionario_en_lista(self, clave, valor, itemPadre=None) | source code